@@ -37,18 +37,20 @@
 #include <QGuiApplication>
 #include <QSortFilterProxyModel>
 #include <QTimer>
+#include <QSessionManager>
 
 // KDE includes
 #include <KAboutApplicationDialog>
 #include <KAuthorized>
 #include <KBugReport>
-#include <KDeclarative/KDeclarative>
 #include <KLocalizedString>
+#include <KLocalizedContext>
 #include <KAboutData>
 #include <KConcatenateRowsProxyModel>
 #include <KSharedConfig>
 #include <KConfigGroup>
 #include <KStandardAction>
+#include <KIO/AccessManager>
 // #include <KSwitchLanguageDialog>
 
 // DiscoverCommon includes
@@ -67,6 +69,7 @@
 class OurSortFilterProxyModel : public QSortFilterProxyModel, public QQmlParserStatus
 {
     Q_OBJECT
+    Q_INTERFACES(QQmlParserStatus)
 public:
     void classBegin() override {}
     void componentComplete() override {
@@ -75,6 +78,17 @@ public:
     }
 };
 
+class KIOAccessManagerFactory : public QQmlNetworkAccessManagerFactory
+{
+public:
+    KIOAccessManagerFactory() = default;
+    ~KIOAccessManagerFactory() = default;
+    QNetworkAccessManager *create(QObject *parent) override
+    {
+        return new KIO::AccessManager(parent);
+    }
+};
+
 DiscoverObject::DiscoverObject(CompactMode mode)
     : QObject()
     , m_engine(new QQmlApplicationEngine)
@@ -82,9 +96,11 @@ DiscoverObject::DiscoverObject(CompactMode mode)
     , m_networkAccessManagerFactory(new CachedNetworkAccessManagerFactory)
 {
     setObjectName(QStringLiteral("DiscoverMain"));
-    KDeclarative::KDeclarative kdeclarative;
-    kdeclarative.setDeclarativeEngine(m_engine);
-    kdeclarative.setupBindings();
+    m_engine->rootContext()->setContextObject(new KLocalizedContext(m_engine));
+    auto factory = m_engine->networkAccessManagerFactory();
+    m_engine->setNetworkAccessManagerFactory(nullptr);
+    delete factory;
+    m_engine->setNetworkAccessManagerFactory(new KIOAccessManagerFactory());
 
     qmlRegisterType<UnityLauncher>("org.kde.discover.app", 1, 0, "UnityLauncher");
     qmlRegisterType<PaginateModel>("org.kde.discover.app", 1, 0, "PaginateModel");
@@ -140,13 +156,18 @@ QStringList DiscoverObject::modes() const
 
 void DiscoverObject::openMode(const QString& _mode)
 {
-    if(!modes().contains(_mode))
-        qWarning() << "unknown mode" << _mode;
+    QObject* obj = rootObject();
+    if (!obj) {
+        qWarning() << "could not get the main object";
+        return;
+    }
+
+    if(!modes().contains(_mode, Qt::CaseInsensitive))
+        qWarning() << "unknown mode" << _mode << modes();
 
     QString mode = _mode;
     mode[0] = mode[0].toUpper();
 
-    QObject* obj = rootObject();
     const QByteArray propertyName = "top"+mode.toLatin1()+"Comp";
     const QVariant modeComp = obj->property(propertyName.constData());
     if (!modeComp.isValid())
@@ -162,7 +183,7 @@ void DiscoverObject::openMimeType(const QString& mime)
 
 void DiscoverObject::openCategory(const QString& category)
 {
-    rootObject()->setProperty("defaultStartup", false);
+    setRootObjectProperty("defaultStartup", false);
     auto action = new OneTimeAction(
         [this, category]() {
             Category* cat = CategoryModel::global()->findCategoryByName(category);
@@ -170,13 +191,13 @@ void DiscoverObject::openCategory(const QString& category)
                 emit listCategoryInternal(cat);
             } else {
                 showPassiveNotification(i18n("Could not find category '%1'", category));
-                rootObject()->setProperty("defaultStartup", false);
+                setRootObjectProperty("defaultStartup", false);
             }
         }
         , this);
 
     if (ResourcesModel::global()->backends().isEmpty()) {
-        connect(ResourcesModel::global(), &ResourcesModel::backendsChanged, action, &OneTimeAction::trigger);
+        connect(ResourcesModel::global(), &ResourcesModel::allInitialized, action, &OneTimeAction::trigger);
     } else {
         action->trigger();
     }
@@ -189,7 +210,7 @@ void DiscoverObject::openLocalPackage(const QUrl& localfile)
         qWarning() << "Trying to open unexisting file" << localfile;
         return;
     }
-    rootObject()->setProperty("defaultStartup", false);
+    setRootObjectProperty("defaultStartup", false);
     auto action = new OneTimeAction(
         [this, localfile]() {
             auto res = ResourcesModel::global()->resourceForFile(localfile);
@@ -197,14 +218,14 @@ void DiscoverObject::openLocalPackage(const QUrl& localfile)
             if (res) {
                 emit openApplicationInternal(res);
             } else {
-                rootObject()->setProperty("defaultStartup", true);
+                setRootObjectProperty("defaultStartup", true);
                 showPassiveNotification(i18n("Couldn't open %1", localfile.toDisplayString()));
             }
         }
         , this);
 
     if (ResourcesModel::global()->backends().isEmpty()) {
-        connect(ResourcesModel::global(), &ResourcesModel::backendsChanged, action, &OneTimeAction::trigger);
+        connect(ResourcesModel::global(), &ResourcesModel::allInitialized, action, &OneTimeAction::trigger);
     } else {
         action->trigger();
     }
@@ -213,7 +234,7 @@ void DiscoverObject::openLocalPackage(const QUrl& localfile)
 void DiscoverObject::openApplication(const QUrl& url)
 {
     Q_ASSERT(!url.isEmpty());
-    rootObject()->setProperty("defaultStartup", false);
+    setRootObjectProperty("defaultStartup", false);
     auto action = new OneTimeAction(
         [this, url]() {
             AbstractResourcesBackend::Filters f;
@@ -221,10 +242,10 @@ void DiscoverObject::openApplication(const QUrl& url)
             auto stream = new StoredResultsStream({ResourcesModel::global()->search(f)});
             connect(stream, &StoredResultsStream::finished, this, [this, url, stream]() {
                 const auto res = stream->resources();
-                if (res.count() == 1) {
+                if (res.count() >= 1) {
                     emit openApplicationInternal(res.first());
                 } else {
-                    rootObject()->setProperty("defaultStartup", true);
+                    setRootObjectProperty("defaultStartup", true);
                     showPassiveNotification(i18n("Couldn't open %1", url.toDisplayString()));
                 }
             });
@@ -232,7 +253,7 @@ void DiscoverObject::openApplication(const QUrl& url)
         , this);
 
     if (ResourcesModel::global()->backends().isEmpty()) {
-        connect(ResourcesModel::global(), &ResourcesModel::backendsChanged, action, &OneTimeAction::trigger);
+        connect(ResourcesModel::global(), &ResourcesModel::allInitialized, action, &OneTimeAction::trigger);
     } else {
         action->trigger();
     }
@@ -260,6 +281,13 @@ void DiscoverObject::integrateObject(QObject* object)
 
     object->installEventFilter(this);
     connect(object, &QObject::destroyed, qGuiApp, &QCoreApplication::quit);
+
+    connect(qGuiApp, &QGuiApplication::commitDataRequest, this, [this](QSessionManager &sessionManager) {
+        if (ResourcesModel::global()->isBusy()) {
+            Q_EMIT preventedClose();
+            sessionManager.cancel();
+        }
+    });
 }
 
 bool DiscoverObject::eventFilter(QObject * object, QEvent * event)
@@ -399,6 +427,17 @@ QWindow* DiscoverObject::rootObject() const
     return qobject_cast<QWindow*>(m_engine->rootObjects().at(0));
 }
 
+void DiscoverObject::setRootObjectProperty(const char* name, const QVariant& value)
+{
+    auto ro = rootObject();
+    if (!ro) {
+        qWarning() << "please check your installation";
+        return;
+    }
+
+    rootObject()->setProperty(name, value);
+}
+
 void DiscoverObject::showPassiveNotification(const QString& msg)
 {
     QTimer::singleShot(100, this, [this, msg](){
