@@ -22,6 +22,7 @@
 
 // Qt includes
 #include <QFont>
+#include <QTimer>
 #include <QDebug>
 
 // KDE includes
@@ -36,12 +37,17 @@
 
 UpdateModel::UpdateModel(QObject *parent)
     : QAbstractListModel(parent)
+    , m_updateSizeTimer(new QTimer(this))
     , m_updates(nullptr)
 {
     connect(ResourcesModel::global(), &ResourcesModel::fetchingChanged, this, &UpdateModel::activityChanged);
     connect(ResourcesModel::global(), &ResourcesModel::updatesCountChanged, this, &UpdateModel::activityChanged);
     connect(ResourcesModel::global(), &ResourcesModel::resourceDataChanged, this, &UpdateModel::resourceDataChanged);
     connect(this, &UpdateModel::toUpdateChanged, this, &UpdateModel::updateSizeChanged);
+
+    m_updateSizeTimer->setInterval(100);
+    m_updateSizeTimer->setSingleShot(true);
+    connect(m_updateSizeTimer, &QTimer::timeout, this, &UpdateModel::updateSizeChanged);
 }
 
 UpdateModel::~UpdateModel() = default;
@@ -89,8 +95,13 @@ void UpdateModel::activityChanged()
     if (m_updates) {
         if (!m_updates->isProgressing()) {
             m_updates->prepare();
-        }
-        setResources(m_updates->toUpdate());
+            setResources(m_updates->toUpdate());
+
+            for(auto item : m_updateItems) {
+                item->setProgress(0);
+            }
+        } else
+            setResources(m_updates->toUpdate());
     }
 }
 
@@ -158,7 +169,10 @@ bool UpdateModel::setData(const QModelIndex &idx, const QVariant &value, int rol
 
         checkResources(apps, newValue);
         Q_ASSERT(idx.data(Qt::CheckStateRole) == value);
-        Q_EMIT dataChanged(idx, idx, { Qt::CheckStateRole });
+
+        //When un/checking some backends will decide to add or remove a bunch of packages, so refresh it all
+        auto m = idx.model();
+        Q_EMIT dataChanged(m->index(0, 0), m->index(m->rowCount()-1, 0), { Qt::CheckStateRole });
         Q_EMIT toUpdateChanged();
 
         return true;
@@ -191,13 +205,17 @@ void UpdateModel::integrateChangelog(const QString &changelog)
     emit dataChanged(idx, idx, { ChangelogRole });
 }
 
-void UpdateModel::setResources(const QList< AbstractResource* >& resources)
+void UpdateModel::setResources(const QList<AbstractResource*>& resources)
 {
+    if (resources == m_resources) {
+        return;
+    }
+    m_resources = resources;
+
     beginResetModel();
     qDeleteAll(m_updateItems);
     m_updateItems.clear();
 
-    const QString importantUpdatesSection = i18nc("@item:inlistbox", "Important Security Updates");
     const QString appUpdatesSection = i18nc("@item:inlistbox", "Application Updates");
     const QString systemUpdateSection = i18nc("@item:inlistbox", "System Updates");
     QVector<UpdateItem*> appItems, systemItems;
@@ -237,12 +255,33 @@ ResourcesUpdatesModel* UpdateModel::backend() const
 int UpdateModel::toUpdateCount() const
 {
     int ret = 0;
+    QSet<QString> packages;
     foreach (UpdateItem* item, m_updateItems) {
+        const auto packageName = item->resource()->packageName();
+        if (packages.contains(packageName)) {
+            continue;
+        }
+        packages.insert(packageName);
         ret += item->checked() != Qt::Unchecked ? 1 : 0;
     }
     return ret;
 }
 
+int UpdateModel::totalUpdatesCount() const
+{
+    int ret = 0;
+    QSet<QString> packages;
+    foreach (UpdateItem* item, m_updateItems) {
+        const auto packageName = item->resource()->packageName();
+        if (packages.contains(packageName)) {
+            continue;
+        }
+        packages.insert(packageName);
+        ret += 1;
+    }
+    return ret;
+}
+
 UpdateItem * UpdateModel::itemFromResource(AbstractResource* res)
 {
     foreach (UpdateItem* item, m_updateItems) {
@@ -278,6 +317,6 @@ void UpdateModel::resourceDataChanged(AbstractResource* res, const QVector<QByte
         dataChanged(index, index, {SizeRole, VersionRole});
     else if (properties.contains("size")) {
         dataChanged(index, index, {SizeRole});
-        Q_EMIT updateSizeChanged();
+        m_updateSizeTimer->start();
     }
 }
