@@ -38,21 +38,21 @@ public:
     QString installedVersion() const override;
     QString license() override;
     int size() override;
-    QUrl screenshotUrl() override;
-    QUrl thumbnailUrl() override;
     QUrl homepage() override;
     QStringList categories() override;
-    AbstractResource::State state() override;
+    AbstractResource::State state() const override;
     QVariant icon() const override;
     QString comment() override;
-    QString name() override;
+    QString name() const override;
     QString packageName() const override;
     bool isTechnical() const override { return m_isTechnical; }
     bool canExecute() const override { return true; }
     void invokeApplication() const override;
     void fetchChangelog() override;
     void fetchScreenshots() override;
+    QUrl url() const override;
     void setState(State state);
+    void setSize(int size) { m_size = size; }
     void setAddons(const AddonList& addons);
 
     void setAddonInstalled(const QString& addon, bool installed);
@@ -65,6 +65,7 @@ public:
     QString m_iconName;
     QList<PackageState> m_addons;
     bool m_isTechnical;
+    int m_size;
 };
 
 #endif // DUMMYRESOURCE_H
