@@ -28,34 +28,29 @@ class AppPackageKitResource : public PackageKitResource
 {
     Q_OBJECT
     public:
-        explicit AppPackageKitResource(const Appstream::Component& data, PackageKitBackend* parent);
+        explicit AppPackageKitResource(const AppStream::Component& data, const QString &packageName, PackageKitBackend* parent);
 
         QString appstreamId() const override;
 
         bool isTechnical() const override;
-        QString name() override;
+        QString name() const override;
         QVariant icon() const override;
         QStringList mimetypes() const override;
         QStringList categories() override;
         QString longDescription() override;
         QUrl homepage() override;
-        bool canExecute() const override;
-        QStringList executables() const override;
-        void invokeApplication() const override;
         QString comment() override;
         QString license() override;
-        QUrl screenshotUrl() override;
-        QUrl thumbnailUrl() override;
         QStringList allPackageNames() const override;
         QList<PackageState> addonsInformation() override;
         QStringList extends() const override;
         void fetchScreenshots() override;
         void fetchChangelog() override;
+        void invokeApplication() const override;
+        bool canExecute() const override { return true; }
 
     private:
-        QStringList findProvides(Appstream::Provides::Kind kind) const;
-
-        const Appstream::Component m_appdata;
+        const AppStream::Component m_appdata;
 };
 
 #endif // APPPACKAGEKITRESOURCE_H
