@@ -48,7 +48,7 @@ class DISCOVERCOMMON_EXPORT PackageKitBackend : public AbstractResourcesBackend
         QSet<AbstractResource*> resourcesByPackageName(const QString& name) const;
 
         ResultsStream* search(const AbstractResourcesBackend::Filters & search) override;
-        ResultsStream* findResourceByPackageName(const QUrl& search) override;
+        ResultsStream* findResourceByPackageName(const QUrl& search);
         int updatesCount() const override;
         bool hasSecurityUpdates() const override;
 
@@ -74,9 +74,11 @@ class DISCOVERCOMMON_EXPORT PackageKitBackend : public AbstractResourcesBackend
         bool hasApplications() const override { return true; }
         static QString locateService(const QString &filename);
 
+        QList<AppStream::Component> componentsById(const QString &id) const;
+
     public Q_SLOTS:
         void reloadPackageList();
-        void refreshDatabase();
+        void transactionError(PackageKit::Transaction::Error, const QString& message);
 
     private Q_SLOTS:
         void getPackagesFinished();
@@ -84,7 +86,6 @@ class DISCOVERCOMMON_EXPORT PackageKitBackend : public AbstractResourcesBackend
         void addPackageArch(PackageKit::Transaction::Info info, const QString &packageId, const QString &summary);
         void addPackageNotArch(PackageKit::Transaction::Info info, const QString &packageId, const QString &summary);
         void packageDetails(const PackageKit::Details& details);
-        void transactionError(PackageKit::Transaction::Error, const QString& message);
         void addPackageToUpdate(PackageKit::Transaction::Info, const QString& pkgid, const QString& summary);
         void getUpdatesFinished(PackageKit::Transaction::Exit,uint);
         void getUpdatesDetailsFinished(PackageKit::Transaction::Exit,uint);
@@ -100,7 +101,7 @@ class DISCOVERCOMMON_EXPORT PackageKitBackend : public AbstractResourcesBackend
         void performDetailsFetch();
         AppPackageKitResource* addComponent(const AppStream::Component& component, const QStringList& pkgNames);
 
-        AppStream::Pool m_appdata;
+        QScopedPointer<AppStream::Pool> m_appdata;
         PackageKitUpdater* m_updater;
         QPointer<PackageKit::Transaction> m_refresher;
         int m_isFetching;
